# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ComputeResource

from pyVmomi.eam.issue.personality.agency import PMIssue

class CannotConfigureSolutions(PMIssue):
   cr: ComputeResource
   solutionsToModify: list[str] = []
   solutionsToRemove: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanObjectExtraAttributes(DynamicData):
   uuid: str
   objPath: str
   objClass: int
   ufn: str
   isHbrCfg: bool
   ownerClusterUuid: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VsanVibScanResult(DynamicData):
   host: HostSystem
   vibName: str
   vibVersion: str
   existingVersion: Optional[str] = None
   maintenanceModeRequired: bool
   rebootRequired: bool
   meetsSystemReq: bool
   pkgDepsMetByHost: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.event import VmEvent

from pyVmomi.vim.vm import Message

class VmMessageErrorEvent(VmEvent):
   message: str
   messageInfo: list[Message] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.sms.storage.replication import DeviceId

class VirtualDiskKey(DeviceId):
   vmInstanceUUID: str
   deviceKey: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class AboutInfo(DynamicData):
   name: str
   fullName: str
   vendor: str
   version: str
   patchLevel: Optional[str] = None
   build: str
   localeVersion: Optional[str] = None
   localeBuild: Optional[str] = None
   osType: str
   productLineId: str
   apiType: str
   apiVersion: str
   instanceUuid: Optional[str] = None
   licenseProductName: Optional[str] = None
   licenseProductVersion: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import XvcQueryFilter

class XvcQuerySpec(DynamicData):
   objectModel: Optional[str] = None
   properties: list[str] = []
   filter: Optional[XvcQueryFilter] = None
   offset: Optional[int] = None
   limit: Optional[int] = None
   returnTotalCount: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class HostServiceTicket(DynamicData):
   host: Optional[str] = None
   port: Optional[int] = None
   sslThumbprint: Optional[str] = None
   sslCertificate: Optional[str] = None
   service: str
   serviceVersion: str
   sessionId: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.VmomiSupport import ManagedObject

class FirmwareSystem(ManagedObject):
   def ResetToFactoryDefaults(self) -> NoReturn: ...
   def BackupConfiguration(self) -> str: ...
   def QueryConfigUploadURL(self) -> str: ...
   def RestoreConfiguration(self, force: bool) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.profile import ApplyProfile

class FirewallProfile(ApplyProfile):
   class RulesetProfile(ApplyProfile):
      key: str

   ruleset: list[RulesetProfile] = []
